@@ -23,7 +23,7 @@ path_to_invalid_file = os.path.join(dirname, 'invalid.xml')
 class TestUnicode(TestCase):
 
     def test_unicode(self):
-        xml = pq(u"<html><p>é</p></html>")
+        xml = pq("<html><p>é</p></html>")
         self.assertEqual(type(xml.html()), str)
         self.assertEqual(str(xml), '<html><p>é</p></html>')
         self.assertEqual(str(xml('p:contains("é")')), '<p>é</p>')
@@ -855,12 +855,6 @@ class TestXMLNamespace(TestCase):
         val = d.text()
         self.assertEqual(repr(val), repr(expected))
 
-    def test_selector_html(self):
-        expected = 'What'
-        d = pq('blah', self.xml.split('?>', 1)[1], parser='html')
-        val = d.text()
-        self.assertEqual(repr(val), repr(expected))
-
     def test_xhtml_namespace(self):
         expected = 'What'
         d = pq(self.xhtml.encode('utf8'), parser='xml')
@@ -932,10 +926,10 @@ class TestWebScrapping(TestCase):
 class TestWebScrappingEncoding(TestCase):
 
     def test_get(self):
-        d = pq(url=u'http://ru.wikipedia.org/wiki/Заглавная_страница',
+        d = pq(url='http://ru.wikipedia.org/wiki/Заглавная_страница',
                method='get')
         print(d)
-        self.assertEqual(d('#pt-login').text(), u'Войти')
+        self.assertEqual(d('#pt-login').text(), 'Войти')
 
 
 class TestWebScrappingTimeouts(TestCase):
